==> instructlab-0.16.0.tar.gz: instructlab-0.16.0/tests/test_lab_download.py <==
# SPDX-License-Identifier: Apache-2.0

# Standard
from unittest.mock import MagicMock, patch

# Third Party
from click.testing import CliRunner
from huggingface_hub.utils import HfHubHTTPError

# First Party
from instructlab import lab


class TestLabDownload:
    # When using `from X import Y` you need to understand that Y becomes part
    # of your module, so you should use `my_module.Y`` to patch.
    # When using `import X`, you should use `X.Y` to patch.
    # https://docs.python.org/3/library/unittest.mock.html#where-to-patch?
    @patch("instructlab.lab.hf_hub_download")
    def test_download(self, mock_hf_hub_download):
        runner = CliRunner()
        with runner.isolated_filesystem():
            result = runner.invoke(
                lab.cli,
                [
                    "--config=DEFAULT",
                    "download",
                ],
            )
            assert (
                result.exit_code == 0
            ), "command finished with an unexpected exit code"
            mock_hf_hub_download.assert_called_once()

    @patch(
        "instructlab.lab.hf_hub_download",
        MagicMock(side_effect=HfHubHTTPError("Could not reach hugging face server")),
    )
    def test_download_error(self):
        runner = CliRunner()
        with runner.isolated_filesystem():
            result = runner.invoke(
                lab.cli,
                [
                    "--config=DEFAULT",
                    "download",
                ],
            )
            assert (
                result.exit_code == 1
            ), "command finished with an unexpected exit code"
            assert "Could not reach hugging face server" in result.output

==> instructlab-0.17.1.tar.gz: instructlab-0.17.1/tests/test_lab_download.py <==
# SPDX-License-Identifier: Apache-2.0

# Standard
from unittest.mock import MagicMock, patch

# Third Party
from click.testing import CliRunner
from huggingface_hub.utils import HfHubHTTPError

# First Party
from instructlab import lab


class TestLabDownload:
    # When using `from X import Y` you need to understand that Y becomes part
    # of your module, so you should use `my_module.Y`` to patch.
    # When using `import X`, you should use `X.Y` to patch.
    # https://docs.python.org/3/library/unittest.mock.html#where-to-patch?
    @patch("instructlab.model.download.hf_hub_download")
    def test_download(self, mock_hf_hub_download):
        runner = CliRunner()
        with runner.isolated_filesystem():
            result = runner.invoke(
                lab.ilab,
                [
                    "--config=DEFAULT",
                    "model",
                    "download",
                ],
            )
            assert (
                result.exit_code == 0
            ), "command finished with an unexpected exit code"
            mock_hf_hub_download.assert_called_once()

    @patch(
        "instructlab.model.download.hf_hub_download",
        MagicMock(side_effect=HfHubHTTPError("Could not reach hugging face server")),
    )
    def test_download_error(self):
        runner = CliRunner()
        with runner.isolated_filesystem():
            result = runner.invoke(
                lab.ilab,
                [
                    "--config=DEFAULT",
                    "model",
                    "download",
                ],
            )
            assert (
                result.exit_code == 1
            ), "command finished with an unexpected exit code"
            assert "Could not reach hugging face server" in result.output
